@@ -39,7 +39,7 @@ $(function(){
                 $('option:selected', $("#geochronometer")).attr('id');
             const languageElement = document.getElementById("language");
             const lang = localStorage.getItem("language");
-          	for (const i in languages.languages_supported) {
+            for (const i in languages.languages_supported) {
                 const s = languages.languages_supported[i];
                 if (lang !== null && lang.startsWith(s.prefix)) {
                     settings.language = s.code;
@@ -56,19 +56,19 @@ $(function(){
             // allow tests to initiate translation, even with unsupported languages
             window.translatePage = function() {
                 IsoplotR.settings.language = this.localStorage.getItem("language");
-            translate();
-        }
+		translate();
+            }
 
-        translate();
-        welcome();
-        $("#INPUT").handsontable({ // add change handler asynchronously
-            afterChange: function(changes,source){
-                getData4Server(); // placed here because we don't want to
-                handson2json();   // call the change handler until after
-            }                     // IsoplotR has been initialised
-        });
-    });
-    rrpc.initialize();
+            translate();
+            welcome();
+            $("#INPUT").handsontable({ // add change handler asynchronously
+		afterChange: function(changes,source){
+                    getData4Server(); // placed here because we don't want to
+                    handson2json();   // call the change handler until after
+		}                     // IsoplotR has been initialised
+            });
+	});
+	rrpc.initialize();
     };
 
     function dnc(){
@@ -311,12 +311,12 @@ $(function(){
 	var d = $("#INPUT").handsontable('getData',r1,c1,r2,c2);
 	var data = cleanData(geochronometer,d,nr,nc);
 	IsoplotR.data4server = {
-		nr, nc, data
+	    nr, nc, data
 	};
 	switch (geochronometer){
 	case  'Ar-Ar':
-		IsoplotR.data4server.J = $('#Jval').val();
-		IsoplotR.data4server.sJ = $('#Jerr').val();
+	    IsoplotR.data4server.J = $('#Jval').val();
+	    IsoplotR.data4server.sJ = $('#Jerr').val();
 	    break;
 	case 'fissiontracks':
 	    switch (IsoplotR.settings.fissiontracks.format){
@@ -537,6 +537,23 @@ $(function(){
 	case 'Th-U':
 	    $('.show4ThU').show();
 	    $('.hide4ThU').hide();
+	    switch (set.Th0i){
+	    case 2:
+		$('.show4assumedTh230corr').hide();
+		$('.show4measuredTh230corr').show();
+		if (set.format>2) $('.show4U8Th2').show();
+		else $('.show4U8Th2').hide();
+		break;
+	    case 3:
+		$('.show4assumedTh230corr').show();
+		$('.show4measuredTh230corr').hide();
+		$('.show4U8Th2').hide();
+		break;
+	    default:
+		$('.show4assumedTh230corr').hide();
+		$('.show4measuredTh230corr').hide();
+		$('.show4U8Th2').hide();
+	    }
 	    switch (set.format){
 	    case 1:
 		$('.show4ThU1').show();
@@ -555,26 +572,6 @@ $(function(){
 		$('.hide4ThU4').hide();
 		break;
 	    }
-	    if (set.format<3){
-		switch (set.detritus){
-		case 2:
-		    $('.show4Th230corr').show();
-		    $('.show4assumedTh230corr').show();
-		    $('.show4measuredTh230corr').hide();
-		    break;
-		case 3:
-		    $('.show4Th230corr').show();
-		    $('.show4assumedTh230corr').hide();
-		    $('.show4measuredTh230corr').show();
-		    break;
-		default:
-		    $('.show4Th230corr').hide();
-		}
-	    } else {
-		$('.show4Th230corr').show();
-		$('.show4assumedTh230corr').show();
-		$('.show4measuredTh230corr').hide();
-	    }
 	    break;
 	case 'Ar-Ar':
 	    $('.show4ArAr').show();
@@ -818,12 +815,20 @@ $(function(){
 	    break;
 	case 'isochron':
 	    $(".hide4isochron").hide();
-	    $(".show4Th230corr").hide();
 	    if (pd.anchor == 2){
 		$('.show4tanchor').show();
 	    } else {
 		$('.show4tanchor').hide();
 	    }
+	    if (geochronometer=='Th-U' & set.format<3){
+		if (pd.y0option==2){
+		    $('.show4y0option2').show();
+		} else if (pd.y0option==3){
+		    $('.show4y0option3').show();
+		} else {
+		    $('.show4y0option1').show();
+		}
+	    }
 	case 'regression':
 	case 'helioplot':
 	    switch (pd.model){
@@ -979,11 +984,11 @@ $(function(){
 	case 'Th-U':
 	    $('#ThU-formats option[value='+set.format+']').
 		prop('selected', 'selected');
-	    $('#detritus option[value='+set.detritus+']').
+	    $('#Th0i option[value='+set.Th0i+']').
 		prop('selected', 'selected');
-	    $('#i2iThU').prop('checked',set.i2i=='TRUE');
-	    $('#Th02').val(set.Th02[0]);
-	    $('#errTh02').val(set.Th02[1]);
+	    $('#U8Th2').val(set.U8Th2);
+	    $('#Th02i').val(set.Th02i[0]);
+	    $('#errTh02i').val(set.Th02i[1]);
 	    $('#Th0U8').val(set.Th02U48[0]);
 	    $('#errTh0U8').val(set.Th02U48[1]);
 	    $('#Th2U8').val(set.Th02U48[2]);
@@ -1211,6 +1216,8 @@ $(function(){
 	case 'isochron':
 	    $('#ThU-isochron-types option[value='+set.ThUtype+']').
 		prop('selected', 'selected');
+	    $('#y0option option[value='+set.y0option+']').
+		prop('selected', 'selected');
 	    $('#UPb-isochron-types option[value='+set.UPbtype+']').
 		prop('selected', 'selected');
 	    $('#anchor-option option[value='+set.anchor+']').
@@ -1433,9 +1440,10 @@ $(function(){
 	    cst.iratio.Pb207Pb204[1] = getNumber('#errPb207Pb204');
 	    break;
 	case 'Th-U':
-	    gcsettings.detritus = getOption("#detritus");
-	    gcsettings.Th02[0] = getNumber("#Th02");
-	    gcsettings.Th02[1] = getNumber("#errTh02");
+	    gcsettings.Th0i = getOption("#Th0i");
+	    gcsettings.U8Th2 = getNumber("#U8Th2");
+	    gcsettings.Th02i[0] = getNumber("#Th02i");
+	    gcsettings.Th02i[1] = getNumber("#errTh02i");
 	    gcsettings.Th02U48[0] = getNumber("#Th0U8");
 	    gcsettings.Th02U48[1] = getNumber("#errTh0U8");
 	    gcsettings.Th02U48[2] = getNumber("#Th2U8");
@@ -1604,6 +1612,7 @@ $(function(){
 	case 'isochron':
 	    pdsettings.UPbtype = getOption("#UPb-isochron-types");
 	    pdsettings.ThUtype = getOption("#ThU-isochron-types");
+	    pdsettings.y0option = getOption("#y0option");
 	    pdsettings.anchor = getOption("#anchor-option")
 	    pdsettings.tanchor = getNumber('#tanchor');
 	    pdsettings.exterr = truefalse('#isochron-exterr');
@@ -1759,7 +1768,6 @@ $(function(){
 	    pdsettings.model = getOption("#evolution-isochron-models");
 	    pdsettings.clabel = $('#clabel').val();
 	    IsoplotR.settings.par.cex = getNumber('#cex');
-	    i2i(geochronometer);
 	    break;
 	default:
 	}
@@ -1785,9 +1793,6 @@ $(function(){
 	case 'K-Ca':
 	    gcsettings.i2i = truefalse("#i2iKCa");
 	    break;
-	case 'Th-U':
-	    gcsettings.i2i = truefalse("#i2iThU");
-	    break;
 	case 'Rb-Sr':
 	    gcsettings.i2i = truefalse("#i2iRbSr");
 	    break;
@@ -2308,10 +2313,23 @@ $(function(){
 	}
     }
     
+    $.Th0i = function(){
+	let set = IsoplotR.settings['Th-U'];
+	if (set.format>2 && set.Th0i>2){
+	    set.Th0i = 0;
+	    $('#Th0i option[value=0]').prop('selected', 'selected');
+	}
+    }
+
+
     $.chooseFormat = function(ID,chronometer){
 	IsoplotR.settings[chronometer].format = getInt(ID);
-	if (chronometer=='fissiontracks'){
+	switch (chronometer){
+	case 'fissiontracks':
 	    $.transformation();
+	    break;
+	case 'Th-U':
+	    $.Th0i();
 	}
 	IsoplotR = populate(IsoplotR,true);
 	errconvert();
@@ -2492,50 +2510,50 @@ $(function(){
 	});
     });
     
-	function displayError(message, err) {
-		console.error(message, err);
-		var par = document.createElement("p");
-		par.setAttribute("class", "ploterror"); 
-		par.textContent = err;
-		var myplot = document.getElementById("myplot");
-		myplot.textContent = '';
-		myplot.appendChild(par);
-}
+    function displayError(message, err) {
+	console.error(message, err);
+	var par = document.createElement("p");
+	par.setAttribute("class", "ploterror"); 
+	par.textContent = err;
+	var myplot = document.getElementById("myplot");
+	myplot.textContent = '';
+	myplot.appendChild(par);
+    }
 
     $("#PLOT").click(function(){
 	update();
 	$("#OUTPUT").hide();
 	$("#myplot").html("<div id='loader' class='blink_me'>Processing...</div>");
 	var plot = function() {
-		rrpc.call("plot", {
-			data: IsoplotR.data4server,
-			width: myplot.offsetWidth,
-			height: myplot.offsetHeight,
-			Rcommand: getRcommand(IsoplotR)
-		}, function(result, err) {
-			if (err) {
-				displayError("Plot failed.", err);
-				return;
-			}
-			var img = document.createElement("img");
-			img.setAttribute("src", result.src[0]);
-			img.setAttribute("width", result.width[0]);
-			img.setAttribute("height", result.height[0]);
-			var myplot = document.getElementById("myplot");
-			myplot.textContent = '';
-			myplot.appendChild(img);
-		});
+	    rrpc.call("plot", {
+		data: IsoplotR.data4server,
+		width: myplot.offsetWidth,
+		height: myplot.offsetHeight,
+		Rcommand: getRcommand(IsoplotR)
+	    }, function(result, err) {
+		if (err) {
+		    displayError("Plot failed.", err);
+		    return;
+		}
+		var img = document.createElement("img");
+		img.setAttribute("src", result.src[0]);
+		img.setAttribute("width", result.width[0]);
+		img.setAttribute("height", result.height[0]);
+		var myplot = document.getElementById("myplot");
+		myplot.textContent = '';
+		myplot.appendChild(img);
+	    });
 	};
 	plot();
 	document.getElementsByTagName("BODY")[0].onresize = function() {
-		if (timeout.variable) {
-			window.clearTimeout(timeout.variable);
-		}
-		timeout.variable = window.setTimeout(plot, 400);
+	    if (timeout.variable) {
+		window.clearTimeout(timeout.variable);
+	    }
+	    timeout.variable = window.setTimeout(plot, 400);
 	};
     });
 
-	$("#RUN").click(function(){
+    $("#RUN").click(function(){
 	update();
 	$("#myplot").empty();
 	$("#OUTPUT").handsontable('clear');
@@ -2543,57 +2561,61 @@ $(function(){
 	$("#OUTPUT").handsontable('setDataAtCell',0,0,'Processing...');
 	$("#OUTPUT").show();
 	rrpc.call("run", {
-		data: IsoplotR.data4server,
-		Rcommand: getRcommand(IsoplotR)
+	    data: IsoplotR.data4server,
+	    Rcommand: getRcommand(IsoplotR)
 	}, function(result, err) {
-		if (err) {
-			displayError('Run failed.', err);
-			return;
-		}
-		$('#OUTPUT').handsontable('populateFromArray', 0, 0,
-			result.data);
-		const hot = $('#OUTPUT').data('handsontable');
-		hot.updateSettings({
-			colHeaders: result.headers
-		});
+	    if (err) {
+		displayError('Run failed.', err);
+		return;
+	    }
+	    $('#OUTPUT').handsontable('populateFromArray', 0, 0,
+				      result.data);
+	    const hot = $('#OUTPUT').data('handsontable');
+	    hot.updateSettings({
+		colHeaders: result.headers
+	    });
 	});
     });
 
-	document.getElementById("PDF").onclick = function() {
+    document.getElementById("PDF").onclick = function() {
 	update();
+	let fname = prompt("Please enter a file name", "IsoplotR.pdf");
 	rrpc.call("pdf", {
-		data: IsoplotR.data4server,
-		Rcommand: getRcommand(IsoplotR)
+	    data: IsoplotR.data4server,
+	    fname: fname,
+	    Rcommand: getRcommand(IsoplotR)
 	}, function(result, err) {
-		if (err) {
-			displayError('Get PDF failed.', err);
-			return;
-		}
-		const downloader = document.getElementById("downloader");
-		downloader.setAttribute("download", result.filename[0]);
-		downloader.setAttribute("href", result.data[0]);
-		downloader.click();
+	    if (err) {
+		displayError('Get PDF failed.', err);
+		return;
+	    }
+	    const downloader = document.getElementById("downloader");
+	    downloader.setAttribute("download", result.filename[0]);
+	    downloader.setAttribute("href", result.data[0]);
+	    downloader.click();
 	});
-	}
+    }
 
-	document.getElementById("CSV").onclick = function() {
-		update();
-		rrpc.call("csv", {
-			data: IsoplotR.data4server,
-			Rcommand: getRcommand(IsoplotR)
-		}, function(result, err) {
-			if (err) {
-				displayError('Get CSV failed.', err);
-				return;
-			}
-			const downloader = document.getElementById("downloader");
-			downloader.setAttribute("download", result.filename[0]);
-			downloader.setAttribute("href", result.data[0]);
-			downloader.click();
-		});
-		}
-	
-	$("#home").click(function(){
+    document.getElementById("CSV").onclick = function() {
+	update();
+	let fname = prompt("Please enter a file name", "ages.csv");
+	rrpc.call("csv", {
+	    data: IsoplotR.data4server,
+	    fname: fname,
+	    Rcommand: getRcommand(IsoplotR)
+	}, function(result, err) {
+	    if (err) {
+		displayError('Get CSV failed.', err);
+		return;
+	    }
+	    const downloader = document.getElementById("downloader");
+	    downloader.setAttribute("download", result.filename[0]);
+	    downloader.setAttribute("href", result.data[0]);
+	    downloader.click();
+	});
+    }
+    
+    $("#home").click(function(){
 	localStorage.setItem("language",IsoplotR.settings.language);
 	$(location).attr('href','home/index.html');
     });
@@ -2601,11 +2623,11 @@ $(function(){
     var IsoplotR;
     var contextual_help = {};
     var dictionary_id = {};
-	var dictionary_class = {};
-	var contextual_help_fallback;
-	var dictionary_id_fallback;
-	var dictionary_class_fallback;
-	var loaded_language = null;
-	const timeout = {};
+    var dictionary_class = {};
+    var contextual_help_fallback;
+    var dictionary_id_fallback;
+    var dictionary_class_fallback;
+    var loaded_language = null;
+    const timeout = {};
     initialise();
 });
